Index: trunk/MagicSoft/Mars/mastro/MAstroCatalog.cc
===================================================================
--- trunk/MagicSoft/Mars/mastro/MAstroCatalog.cc	(revision 4434)
+++ trunk/MagicSoft/Mars/mastro/MAstroCatalog.cc	(revision 4517)
@@ -11,5 +11,5 @@
 ! * provided that the above copyright notice appear in all copies and
 ! * that both that copyright notice and this permission notice appear
-! * in supporting documentation. It is provided "as is" without express
+! * in supporting documentation. It is provided "as is" without expressed
 ! * or implied warranty.
 ! *
@@ -17,4 +17,5 @@
 !
 !   Author(s): Thomas Bretz, 03/2004 <mailto:tbretz@astro.uni-wuerzburg.de>
+!   Author(s): Robert Wagner, 08/2004 <mailto:rwagner@mppmu.mpg.de>
 !
 !   Copyright: MAGIC Software Development, 2002-2004
@@ -225,5 +226,5 @@
 // --------------------------------------------------------------------------
 //
 // Snippet to for reading ctalog files.
 //
 TString MAstroCatalog::FindToken(TString &line, Char_t tok)
@@ -356,4 +357,5 @@
         star->SetRaDec(ra0, dec0, mag);
         star->SetName(name);
+
         if (star->Angle(fRaDec)*TMath::RadToDeg()>fRadiusFOV)
         {
@@ -692,4 +694,25 @@
 
     return add;
+}
+
+// --------------------------------------------------------------------------
+//
+// Add an object to the star catalog manually.
+//
+Int_t MAstroCatalog::AddObject(Float_t ra, Float_t dec, Float_t mag, TString name)
+{
+    SetBit(kHasChanged);
+
+    MVector3 *star = new MVector3();
+    star->SetRaDec(ra, dec, mag);
+    star->SetName(name);
+
+    if (star->Angle(fRaDec)*TMath::RadToDeg()<=fRadiusFOV) {
+      fList.Add(star);
+    } else {
+      delete(star);
+    }
+    
+    return 1;
 }
 
@@ -225,5 +226,5 @@
 // --------------------------------------------------------------------------
 //
-// Snippet to for reading ctalog files.
+// Snippet to for reading catalog files.
 //
 TString MAstroCatalog::FindToken(TString &line, Char_t tok)
